@@ -4,7 +4,6 @@ from pathlib import Path
 from typing import TYPE_CHECKING, TypeVar
 
 import asyncstdlib
-from asyncstdlib import heapq
 from discord.app_commands import Choice, Transformer
 from discord.ext import commands
 from rapidfuzz import fuzz
@@ -26,7 +25,6 @@ except ImportError:
 
 
 if TYPE_CHECKING:
-
     PlaylistConverter = TypeVar("PlaylistConverter", bound=list[PlaylistModel])
 else:
 
@@ -38,7 +36,11 @@ else:
             try:
                 playlists = await ctx.pylav.playlist_db_manager.get_playlist_by_name_or_id(arg)
             except EntryNotFoundException as e:
-                raise commands.BadArgument(_("Playlist with name or id `{arg}` not found").format(arg=arg)) from e
+                raise commands.BadArgument(
+                    _(
+                        "A playlist with the name or identifier `{user_input_variable_do_not_translate}` was not found."
+                    ).format(user_input_variable_do_not_translate=arg)
+                ) from e
             return playlists
 
         @classmethod
@@ -50,7 +52,6 @@ else:
 
         @classmethod
         async def autocomplete(cls, interaction: DISCORD_INTERACTION_TYPE, current: str) -> list[Choice]:
-
             if not current:
                 playlists = await interaction.client.pylav.playlist_db_manager.get_bundled_playlists()
                 return [
@@ -72,7 +73,7 @@ else:
                     [-ord(i) for i in name],
                 )
 
-            extracted = await heapq.nlargest(asyncstdlib.iter(playlists), n=25, key=_filter)
+            extracted = await asyncstdlib.heapq.nlargest(asyncstdlib.iter(playlists), n=25, key=_filter)
             return [
                 Choice(name=shorten_string(await e.fetch_name(), max_length=100), value=f"{e.id}") for e in extracted
             ]
