@@ -19,7 +19,7 @@ class FailingAddress:
 
 @dataclasses.dataclass(repr=True, frozen=True, kw_only=True, slots=True)
 class Details:
-    ipBlock: IPBlock | dict
+    ipBlock: IPBlock
     failingAddresses: list[FailingAddress]
     rotateIndex: str
     ipIndex: str
@@ -27,20 +27,11 @@ class Details:
     currentAddressIndex: str
     blockIndex: str
 
-    def __post_init__(self):
-        temp = []
-        for s in self.failingAddresses:
-            if isinstance(s, FailingAddress) or (isinstance(s, dict) and (s := FailingAddress(**s))):
-                temp.append(s)
-        object.__setattr__(self, "failingAddresses", temp)
-        if isinstance(self.ipBlock, dict):
-            object.__setattr__(self, "ipBlock", IPBlock(**self.ipBlock))
-
 
 @dataclasses.dataclass(repr=True, frozen=True, kw_only=True, slots=True)
 class Status:
+    details: Details | None
     type: Literal["RotatingIpRoutePlanner", "NanoIpRoutePlanner", "RotatingNanoIpRoutePlanner"] | None = None
-    details: Details | None | dict = None
 
     def __post_init__(self):
         if isinstance(self.details, dict):
